# encoding:utf8

from mgamedev.py_lib.decorator import singleton
import paramiko
import os
import sys
import time
import threading
import string
import logging
import ftplib


def _log_noempty(strarr):
    if len(strarr) == 0:
        pass
    else:
        logging.info("CONSOLE-->%s)" % (strarr))


@singleton
class RemoteCtrl():

    def __init__(self, host, port=22, usr="root", pwd=None, keyfile=None):
        self.HOST = host
        self.PORT = int(port)
        self._name = usr
        self._pwd = pwd
        self._keyfile = keyfile

        self._ssh = None
        self._sftp = None
        self._ftp = None

    def _get_sslcon(self):
        if (self._ssh):
            return self._ssh
        try:
            con = paramiko.SSHClient()
            con.set_missing_host_key_policy(paramiko.AutoAddPolicy())
            if self._keyfile:
                con.connect(self.HOST, self.PORT, "",
                            key_filename=self._keyfile)
            else:
                con.connect(self.HOST, self.PORT, username=self._name,
                            password=self._pwd)
            logging.info(
                "SSH connect to the host-->>(%s:%s) successful!" % (self.HOST, self.PORT))
            self._ssh = con
            return con
        except:
            logging.error(
                "SSH connect to the host-->>(%s:%s) failed!" % (self.HOST, str(self.PORT)))
            sys.exit()
        return None

    def _get_sftp(self):
        if (self._sftp):
            return self._sftp
        try:
            con = paramiko.Transport((self.HOST, 22))
            con.connect(username=self._name, password=self._pwd)
            sftp = paramiko.SFTPClient.from_transport(con)
            self._sftp = sftp
            return sftp
        except:
            logging.error(
                "SFtp connect to the host-->>(%s) failed!" % self.HOST)
            sys.exit()

    def _get_ftp(self):
        if (self._ftp):
            return self._ftp
        ftp = ftplib.FTP()
        ftp.connect(self.HOST, 21)
        ftp.set_pasv(False)
        ftp.login(self._name, self._pwd)
        self._ftp = ftp
        return ftp

    def close(self):
        if self._sftp:
            self._sftp.close()
            self._sftp = None
        if self._ssh:
            self._ssh.close()
            self._ssh = None
        if self._ftp:
            self._ftp.close()
        self.HOST = None
        self._name = None
        self._pwd = None
        logging.info("Remote connect closed!")

    # (discard)
    def commit_file(self, localfile, netfile, proce_cb=None):
        return self.sftp_upload(localfile, netfile, proce_cb)

    # 执行远端命令
    def ssh_command(self, strcmd):
        stdin, stdout, stderr = self._get_sslcon().exec_command(strcmd)
        return stdout.read()

    # 下载目标文件
    def chkout_file(self, netfile, localfile):
        self._get_sftp().get(netfile, localfile)

    # 压缩目标目录
    def zip_tardir(self, netfile, netdir):
        stdin, stdout, stderr = self._get_sslcon().exec_command(
            "zip -q -r %s %s" % (netdir, netfile))
        _log_noempty(stdout.readlines())
        _log_noempty(stderr.readlines())

    # sftp上传文件
    def sftp_upload(self, localfile, netfile, proce_cb=None):
        logging.info("Uploading the file from local <%s> to <%s>" %
                     (localfile, netfile))
        return self._get_sftp().put(localfile, netfile, proce_cb)

    # ftp 上传文件
    def ftp_upload(self, localfile, netfile, proce_cb=None):
        logging.info("Uploading the file from local <%s> to <%s>" %
                     (localfile, netfile))
        ftp = self._get_ftp()
        BUFF_SIZE = 1024
        with open(localfile, "rb") as fp:
            ftp.storbinary("STOR " + netfile, fp, BUFF_SIZE)
        logging.info("Upload suc!")

if __name__ == "__main__":
    UNAME = "root"
    IP = "192.168.62.144"
    PWD = "123456"
    cli = RemoteCtrl(IP, UNAME, PWD)
    print(cli.ssh_command("ls"))
    cli.close()



import struct  
  
_DELTA = 0x9E3779B9  
  
def _long2str(v, w):  
    n = (len(v) - 1) << 2  
    if w:  
        m = v[-1]  
        if (m < n - 3) or (m > n): return ''  
        n = m  
    s = struct.pack('<%iL' % len(v), *v)  
    return s[0:n] if w else s  
  
def _str2long(s, w):  
    n = len(s)  
    m = (4 - (n & 3) & 3) + n  
    s = s.ljust(m, "\0")  
    v = list(struct.unpack('<%iL' % (m >> 2), s))  
    if w: v.append(n)  
    return v  
  
def encrypt(str, key):  
    if str == '': return str  
    v = _str2long(str, True)  
    k = _str2long(key.ljust(16, "\0"), False)  
    n = len(v) - 1  
    z = v[n]  
    y = v[0]  
    sum = 0  
    q = 6 + 52 // (n + 1)  
    while q > 0:  
        sum = (sum + _DELTA) & 0xffffffff  
        e = sum >> 2 & 3  
        for p in xrange(n):  
            y = v[p + 1]  
            v[p] = (v[p] + ((z >> 5 ^ y << 2) + (y >> 3 ^ z << 4) ^ (sum ^ y) + (k[p & 3 ^ e] ^ z))) & 0xffffffff  
            z = v[p]  
        y = v[0]  
        v[n] = (v[n] + ((z >> 5 ^ y << 2) + (y >> 3 ^ z << 4) ^ (sum ^ y) + (k[n & 3 ^ e] ^ z))) & 0xffffffff  
        z = v[n]  
        q -= 1  
    return _long2str(v, False)  
  
def decrypt(str, key):  
    if str == '': return str  
    v = _str2long(str, False)  
    k = _str2long(key.ljust(16, "\0"), False)  
    n = len(v) - 1  
    z = v[n]  
    y = v[0]  
    q = 6 + 52 // (n + 1)  
    sum = (q * _DELTA) & 0xffffffff  
    while (sum != 0):  
        e = sum >> 2 & 3  
        for p in xrange(n, 0, -1):  
            z = v[p - 1]  
            v[p] = (v[p] - ((z >> 5 ^ y << 2) + (y >> 3 ^ z << 4) ^ (sum ^ y) + (k[p & 3 ^ e] ^ z))) & 0xffffffff  
            y = v[p]  
        z = v[n]  
        v[0] = (v[0] - ((z >> 5 ^ y << 2) + (y >> 3 ^ z << 4) ^ (sum ^ y) + (k[0 & 3 ^ e] ^ z))) & 0xffffffff  
        y = v[0]  
        sum = (sum - _DELTA) & 0xffffffff  
    return _long2str(v, True)

# if __name__ =="__main__": 
# 	print decrypt(encrypt('hello hex game!', 'dwb.ren'), 'dwb.ren') 
# 	print encrypt("hello hex game!" , "dwb.ren")
# 	fileobj = open("aaa.txt" , "w+")
# 	fileobj.write(encrypt("hello hex game!" , "dwb.ren"))
# 	fileobj.close()
# 		# , key)




#!/usr/bin/python
# -*- coding: utf-8 -*-

# ----------------------------------------------------------------------------
# Read simple data file ex: json // xml // plist //  zip
# ----------------------------------------------------------------------------
import os

# public functions
# ============================comman==============================
# 读取文件的md5


def getFileMd5(filepath):
    import hashlib
    m5 = hashlib.md5()
    data = file(filepath, "rb")
    while True:
        b = data.read(1024)
        if not b:
            break
        m5.update(b)
    data.close()
    return m5.hexdigest()

# ============================json=================================
# 读取json文件 返回一个字典


def readJsonFile(filename, mod="r+"):
    import json
    f = file(filename, mod)
    ret = json.loads(f.read().decode("utf-8"))
    f.close()
    return ret

# ============================plist===============================


def readPlistFile(filename):
    import plistlib
    pl = plistlib.readPlist(filename)
    return pl

# ============================xml=================================
# 读取Android的value文件夹下的string.xml文件


def readAndroid_stringxml(file, valuestring):
    from xml.etree import ElementTree
    root = ElementTree.parse(file)

    list_children = root.getiterator("resources")
    for node in list_children:
        print(node)
        if node.tag == "resources":
            for item in node:
                if item.tag == "string":
                    item.text = valuestring

# ===========================zip==================================
# 解压一个zip文件到制定目录


def unzipFile(zippath, tarpath=os.path.join(os.getcwd())):
    import zipfile
    import shutil

    if not os.path.isdir(tarpath):
        os.mkdir(tarpath)

    # unzip to download tarpath
    unzipobj = zipfile.ZipFile(zippath, 'r')
    zipname = os.path.split(zippath)[1]
    downpath = os.path.join(tarpath, os.path.splitext(zipname)[0])
    for filename in unzipobj.namelist():
        filepath = os.path.join(tarpath, filename)
        filepath = filepath.replace("/", '\\')

        # path
        if filepath.endswith("\\"):
            filepath = filepath[:-1]
            if os.path.isdir(filepath):
                shutil.rmtree(filepath)
            os.mkdir(filepath)
            print("unzip the dir %s " % filepath)
        # file
        else:

            path_file = os.path.split(filepath)[0]
            if not os.path.isdir(path_file):
                os.mkdir(path_file)

            data = unzipobj.read(filename)
            fileobj = open(filepath, "w+b")
            fileobj.write(data)
            print("unzip the file %s " % fileobj)
            fileobj.close()

    unzipobj.close()



#!python
import os
import sys
from xml.etree import ElementTree
from PIL import Image


def tree_to_dict(tree):
    d = {}
    for index, item in enumerate(tree):
        if item.tag == 'key':
            if tree[index + 1].tag == 'string':
                d[item.text] = tree[index + 1].text
            elif tree[index + 1].tag == 'true':
                d[item.text] = True
            elif tree[index + 1].tag == 'false':
                d[item.text] = False
            elif tree[index + 1].tag == 'dict':
                d[item.text] = tree_to_dict(tree[index + 1])
    return d


def gen_png_from_plist(pfile, tfile):
    file_path = pfile.replace('.plist', '')
    big_image = Image.open(tfile)
    root = ElementTree.fromstring(open(pfile, 'r').read())
    plist_dict = tree_to_dict(root[0])

    def to_list(basestr): \
        return basestr.replace('{', '').replace('}', '').split(',')

    for k, v in plist_dict['frames'].items():
        rectlist = to_list(v['frame'])
        width = int(rectlist[3] if v['rotated'] else rectlist[2])
        height = int(rectlist[2] if v['rotated'] else rectlist[3])
        box = (
            int(rectlist[0]),
            int(rectlist[1]),
            int(rectlist[0]) + width,
            int(rectlist[1]) + height,
        )
        sizelist = [int(x) for x in to_list(v['sourceSize'])]
        rect_on_big = big_image.crop(box)

        if v['rotated']:
            rect_on_big = rect_on_big.rotate(90)

        result_image = Image.new('RGBA', sizelist, (0, 0, 0, 0))
        if v['rotated']:
            result_box = (
                (sizelist[0] - height) / 2,
                (sizelist[1] - width) / 2,
                (sizelist[0] + height) / 2,
                (sizelist[1] + width) / 2
            )
        else:
            result_box = (
                (sizelist[0] - width) / 2,
                (sizelist[1] - height) / 2,
                (sizelist[0] + width) / 2,
                (sizelist[1] + height) / 2
            )
        result_image.paste(rect_on_big, result_box, mask=0)

        if not os.path.isdir(file_path):
            os.mkdir(file_path)
        outfile = (file_path + '/' + k).replace('gift_', '')
        print outfile, "generated"
        result_image.save(outfile)


if __name__ == '__main__':
    filename = sys.argv[1]
    plist_filename = filename + '.plist'
    png_filename = filename + '.png'
    if (os.path.exists(plist_filename) and os.path.exists(png_filename)):
        gen_png_from_plist(plist_filename, png_filename)
    else:
        print "make sure you have boith plist and png files in the same directory"



#!/usr/bin/python
# -*- coding: utf-8 -*-

# ----------------------------------------------------------------------------
# Write dict to file ex: json // xml // plist //  zip
# ----------------------------------------------------------------------------
import os

# common functions
#============================common=================================


def write2XXTeaFile(strvalue, tarfile, key):
    from lib import *
    fobj = file(tarfile, 'w+')
    fobj.write(xxtea.encrypt(strvalue, key))
    fobj.close()

# public functions
#============================json=================================
# 写入json文件


def write2Json(dict, tarfile, mod="w+"):
    import json
    jsonobj = open(tarfile,  mod)  # json-file
    json.dump(dict, jsonobj, sort_keys=True, indent=4)
    jsonobj.close()


#===========================zip==================================
# 压缩一个文件夹到指定zip
# 把整个文件夹内的文件打包
def write2Zip(zippath, tarfile):
    import zipfile
    filelist = []
    if os.path.isfile(zippath):
        filelist.append(zippath)
    else:
        for dirpath, dirnames, filenames in os.walk(zippath):
            for filename in filenames:
                filelist.append(os.path.join(dirpath, filename))

    f = zipfile.ZipFile(tarfile, 'w', zipfile.ZIP_DEFLATED)
    for tar in filelist:
        arcname = tar[len(zippath):]
        f.write(tar, arcname)
    f.close()



#encoding:utf8 

import os 
import string

DIRTY_WORDS = ["FUCK", "FXXK"]
output = []

def iter_path(tpath):
    print("Chking the path-->>", tpath)
    for filename in os.listdir(tpath):
        fileobj = os.path.join(tpath, filename)
        if os.path.isdir(fileobj):
            iter_path(fileobj)
        else:
            for dword in DIRTY_WORDS:
                if string.find(filename.upper(), dword) != -1:
                    output.append(filename)
            

iter_path(os.getcwd())
print (output, "--->>output")


# encoding:utf8
from functools import wraps


def singleton(cls):
    instances = {}

    @wraps(cls)
    def getinstance(*args, **kw):
        if cls not in instances:
            instances[cls] = cls(*args, **kw)
        return instances[cls]
    return getinstance



# encoding:utf8
''' 2017-8-24 pylint fix '''
import os
import sys
import json
import shutil
import logging
import plistlib


def path_fmt(path):
    ''' 路径兼容 '''
    path = path.replace("\n", "")
    return path.replace("/", os.sep)


class BatchPackimg(object):
    ''' 文件打包工具 '''
    _basepath = None   # 打包路径
    _tarpath = None   # 目标路径
    _pconfs = []     # 打包配置

    RESCONFIG_FILENAME = "resconf.data"  # 打包文件配置文件名

    @classmethod
    def _handle_etc1cmd_316(cls, pconf):
        ''' 
        这里是兼容316的官方etc1的
        打包方法独立的打包命令

        '''
        # pardir
        pardir = os.path.join(
            cls._tarpath, pconf["pardir"].replace("/", os.sep))
        if not os.path.isdir(pardir):
            os.makedirs(pardir)
        cmdrgb_str = "TexturePacker --sheet {out_file} --data {plist_name} \
                    --texture-format pkm --format {fmt_type} \
                    --opt ETC1 --size-constraints POT --disable-auto-alias \
                    --max-width 2048 --max-height 2048 {dir_name}"
        cmda_str = "TexturePacker --sheet {out_file} --data {plist_name} \
                    --texture-format pkm --format {fmt_type} --opt ETC1_A \
                    --size-constraints POT --disable-auto-alias \
                    --max-width 2048 --max-height 2048 {dir_name}"
        fmtrgb_str = dict(
            out_file=os.path.join(cls._tarpath, pconf["tarfile"] + ".pkm"),
            plist_name=os.path.join(cls._tarpath, pconf["tarfile"] + ".plist"),
            fmt_type="cocos2d",
            dir_name=os.path.join(cls._basepath, pconf["packpath"])
        )
        fmta_str = dict(
            out_file=os.path.join(
                cls._tarpath, pconf["tarfile"] + ".pkm@alpha"),
            plist_name=os.path.join(
                cls._tarpath, pconf["tarfile"] + ".plist@alpha"),
            fmt_type="cocos2d",
            dir_name=os.path.join(cls._basepath, pconf["packpath"])
        )
        ret = cmdrgb_str.format(out_file=fmtrgb_str["out_file"],
                                plist_name=fmtrgb_str["plist_name"],
                                fmt_type=fmtrgb_str["fmt_type"],
                                dir_name=fmtrgb_str["dir_name"])
        os.system(ret)
        ret = cmda_str.format(out_file=fmta_str["out_file"],
                              plist_name=fmta_str["plist_name"],
                              fmt_type=fmta_str["fmt_type"],
                              dir_name=fmta_str["dir_name"])
        os.system(ret)

    @classmethod
    def _handle_etc1cmd(cls, pconf):
        ''' 
        pconf是单条配置
        *兼容pvr 用类似工具
        '''
        # no-use files
        noulist = []
        # pardir
        pardir = os.path.join(
            cls._tarpath, pconf["pardir"].replace("/", os.sep))
        if not os.path.isdir(pardir):
            os.makedirs(pardir)

        # pack rgb + alpha
        cmdrgb_str = "TexturePacker --sheet {out_file} --data {plist_name} \
                    --texture-format pkm --format {fmt_type} --opt ETC1 \
                    --size-constraints POT --disable-auto-alias \
                    --max-width 2048 --max-height 2048 {dir_name}"
        cmda_str = "TexturePacker --sheet {out_file} --data {plist_name} \
                    --texture-format pkm --format {fmt_type} --opt ETC1_A \
                    --size-constraints POT --disable-auto-alias \
                    --max-width 2048 --max-height 2048 {dir_name}"
        fmtrgb_str = dict(
            out_file=os.path.join(cls._tarpath, pconf["tarfile"] + ".pkm"),
            plist_name=os.path.join(cls._tarpath, pconf["tarfile"] + ".plist"),
            fmt_type="cocos2d-v2",
            dir_name=os.path.join(cls._basepath, pconf["packpath"])
        )
        fmta_str = dict(
            out_file=os.path.join(
                cls._tarpath, pconf["tarfile"] + "_alpha.pkm"),
            plist_name=os.path.join(
                cls._tarpath, pconf["tarfile"] + "_alpha.plist"),
            fmt_type="cocos2d-v2",
            dir_name=os.path.join(cls._basepath, pconf["packpath"])
        )
        ret = cmdrgb_str.format(out_file=fmtrgb_str["out_file"],
                                plist_name=fmtrgb_str["plist_name"],
                                fmt_type=fmtrgb_str["fmt_type"],
                                dir_name=fmtrgb_str["dir_name"])
        print ret
        os.system(ret)
        ret = cmda_str.format(out_file=fmta_str["out_file"],
                              plist_name=fmta_str["plist_name"],
                              fmt_type=fmta_str["fmt_type"],
                              dir_name=fmta_str["dir_name"])
        os.system(ret)
        noulist.append(fmtrgb_str["out_file"])
        noulist.append(fmta_str["out_file"])
        noulist.append(fmta_str["plist_name"])

        # etc1_packdir
        outdir = cls._tarpath
        fname = pconf["tarfile"].split(os.sep)[-1]
        fnamehalf = pconf["tarfile"]
        tmpp = os.path.join(outdir, fnamehalf)
        tmpall = os.path.join(outdir, fnamehalf) + os.sep + fname + "_all.png"
        tmprgb = os.path.join(outdir, fnamehalf) + os.sep + fname + ".png"
        tmpa = os.path.join(outdir, fnamehalf) + os.sep + fname + "_alpha.png"

        # pkm 转 png
        binpath = os.environ["texturetool"]
        etcbin = os.path.join(binpath, "etcpack")
        convertbin = os.path.join(binpath, "convert")
        gzipbin = os.path.join(binpath, "gzip")

        cmdrgb_str = "cd {binpath} && {etcpack} {bfile} {ofile} \
                -ext PNG".format(binpath=binpath, etcpack=etcbin,
                                 bfile=fmtrgb_str["out_file"], ofile=tmpp)
        cmda_str = "cd {binpath} && {etcpack} {bfile} {ofile} \
                -ext PNG".format(binpath=binpath, etcpack=etcbin,
                                 bfile=fmta_str["out_file"], ofile=tmpp)
        print cmdrgb_str
        os.system(cmdrgb_str)
        os.system(cmda_str)

        # convert a+rgb
        cmdconv_str = "cd {binpath} && {convert} -append {rgb} {a}\
                     {all}".format(binpath=binpath, convert=convertbin,
                                   rgb=tmprgb, a=tmpa, all=tmpall)
        print cmdconv_str
        logging.info('cmdconv_str--->>>%s', cmdconv_str)
        os.system(cmdconv_str)

        # final 转etcpack
        cmdetc_str = "cd {binpath} && {etcpack} {all} {tar} -c etc1".format(
            binpath=binpath, etcpack=etcbin, all=tmpall, tar=tmpp)
        os.system(cmdetc_str)

        # gzip all pkm
        nosuffix = os.path.join(outdir, fnamehalf) + os.sep + fname
        retpkm = os.path.join(outdir, fnamehalf) + os.sep + fname + "_all.pkm"
        os.renames(retpkm, nosuffix)
        cmdgzip_str = "{gzipbin} {tarfile} -f".format(
            gzipbin=gzipbin, tarfile=nosuffix)
        print cmdgzip_str
        os.system(cmdgzip_str)

        # move and remove
        gzret = nosuffix + ".gz"
        ret = fmtrgb_str["out_file"].replace('.pkm', '.png')
        if os.path.isfile(ret):
            os.remove(ret)
        print(gzret, "--->>gzret")
        print(fmtrgb_str["out_file"].replace(".pkm", ".png"), "fmtrgb")
        os.rename(gzret, fmtrgb_str["out_file"].replace(".pkm", ".png"))

        # os.rename(tarpng + ".zip", tarpng + ".png")

        # remove unuse
        noulist.append(tmpp)
        for fobj in noulist:
            if os.path.isdir(fobj):
                shutil.rmtree(fobj)
            else:
                os.remove(fobj)
        # sys.exit()

    @classmethod
    def _handle_pvrcmd(cls, pconf):
        '''
        pconf是单条配置
        *pvr 一定是pot
        '''
        cmd_str = "TexturePacker --sheet {out_file} --data {plist_name} \
                --texture-format pvr3 --force-squared --format {fmt_type} \
                --opt PVRTC4 --disable-auto-alias --max-width 2048 \
                --max-height 2048 {dir_name}"
        fmtdic = dict(
            out_file=os.path.join(cls._tarpath, pconf["tarfile"] + ".pvr"),
            plist_name=os.path.join(cls._tarpath, pconf["tarfile"] + ".plist"),
            fmt_type="cocos2d-v2",
            dir_name=os.path.join(cls._basepath, pconf["packpath"])
        )
        pardir = os.path.join(
            cls._tarpath, pconf["pardir"].replace("/", os.sep))
        if not os.path.isdir(pardir):
            os.makedirs(pardir)

        ret = cmd_str.format(out_file=fmtdic["out_file"],
                             plist_name=fmtdic["plist_name"],
                             fmt_type=fmtdic["fmt_type"],
                             dir_name=fmtdic["dir_name"])

        logging.info(ret)
        if (os.path.isfile(fmtdic["out_file"])):
            os.remove(fmtdic["out_file"])
            os.remove(fmtdic["plist_name"])
        os.system(ret)
        if (os.path.isfile(fmtdic["out_file"])):
            if fmtdic["out_file"].endswith(".pvr"):
                os.rename(fmtdic["out_file"],
                          fmtdic["out_file"].replace(".pvr", ".png"))
        if (os.path.isfile(fmtdic["plist_name"])):
            if fmtdic["plist_name"].endswith(".plist"):
                plistdic = plistlib.readPlist(fmtdic["plist_name"])
                plistdic["metadata"]["realTextureFileName"] = \
                    plistdic["metadata"]["realTextureFileName"].replace(
                    ".pvr", ".png")
                plistdic["metadata"]["textureFileName"] = \
                    plistdic["metadata"]["textureFileName"].replace(
                    ".pvr", ".png")
                plistdic["metadata"].pop("smartupdate")
                plistlib.writePlist(plistdic, fmtdic["plist_name"])

    @classmethod
    def _handle_pngcmd(cls, pconf, extparam):
        '''pconf是单条配置'''

        cmd_str = "{TexturePacker} --sheet {out_file} --data {plist_name} \
                    --texture-format png8 --force-squared \
                    --format {fmt_type} --size-constraints NPOT \
                    --disable-auto-alias --max-width 2048 \
                    --multipack \
                    --max-height 2048  %s {dir_name}" % extparam
        cmd_str = "{TexturePacker} --sheet {out_file} --data {plist_name} \
                    --texture-format png8 --force-squared \
                    --format {fmt_type} --size-constraints NPOT \
                    --disable-auto-alias --max-width 2048 \
                    --max-height 2048  %s {dir_name}" % extparam

        fmtdic = dict(
            out_file=os.path.join(cls._tarpath, pconf["tarfile"] + ".png"),
            plist_name=os.path.join(cls._tarpath, pconf["tarfile"] + ".plist"),
            # fmt_type="cocos2d",
            fmt_type="cocos2d-v2",
            dir_name=os.path.join(cls._basepath, pconf["packpath"])
        )
        # chk pardir
        if pconf["pardir"]:
            pardir = os.path.join(
                cls._tarpath, pconf["pardir"].replace("/", os.sep))
            if not os.path.isdir(pardir):
                os.makedirs(pardir)

        ret = cmd_str.format(TexturePacker="/usr/local/bin/TexturePacker",
                             out_file=fmtdic["out_file"],
                             plist_name=fmtdic["plist_name"],
                             fmt_type=fmtdic["fmt_type"],
                             dir_name=fmtdic["dir_name"])
        logging.info(ret)
        os.system(ret)
        if (os.path.isfile(fmtdic["out_file"])):
            if fmtdic["out_file"].endswith(".pvr"):
                os.rename(fmtdic["out_file"],
                          fmtdic["out_file"].replace(".pvr", ".png"))

        cls.del_smartudpate(fmtdic["plist_name"])
        cls.add_dirname(fmtdic["plist_name"], "xl")

    @classmethod
    def _do_packlist(cls, extparam):
        '''遍历配置来打包'''
        if cls._packtype == "png":
            for pconf in cls._pconfs:
                cls._handle_pngcmd(pconf, extparam)
        elif cls._packtype == "pvr":
            for pconf in cls._pconfs:
                cls._handle_pvrcmd(pconf)
        elif cls._packtype == "etc1":
            for pconf in cls._pconfs:
                cls._handle_etc1cmd_316(pconf)
        else:
            logging.error(
                "Chk the pack type first!\
                 It's not support <{}> yet".format(cls._packtype))
            sys.exit()

    @classmethod
    def chk_packconf(cls, key):
        '''获取资源打包配置'''
        print(cls._resconf, "--->>cls.resconf")
        if not cls._resconf.has_key(key):
            logging.error("There is no config for pack <%s>", key)
            logging.error("Sys out!")
            sys.exit()
        resconf = cls._resconf[key]
        pconf = {}
        pconf["packpath"] = resconf["from"]
        pconf["tarfile"] = resconf["to"]
        pconf["pardir"] = resconf["to"].split("/")[0] if \
            len(resconf["to"].split("/")) > 1 else None

        logging.debug("out logging pconf is %s", pconf)
        return pconf

    @classmethod
    def get_resconfig(cls):
        '''获取资源打包配置'''
        jfile = os.path.join(cls._basepath, cls.RESCONFIG_FILENAME)
        fobj = open(jfile, "r")
        fcont = fobj.read().decode('utf-8')
        fobj.close()
        return json.loads(fcont)

    @classmethod
    def del_smartudpate(cls, plistfile):
        pdic = plistlib.readPlist(plistfile)
        # smart
        if pdic.has_key("metadata"):
            if pdic["metadata"].has_key("smartupdate"):
                pdic["metadata"].pop("smartupdate")
        plistlib.writePlist(pdic, plistfile)

    @classmethod
    def add_dirname(cls, plistfile, dirname):
        pdic = plistlib.readPlist(plistfile)
        for k, v in (pdic["frames"].items()):
            if k.find('/') == -1:
                item = pdic["frames"].pop(k)
                pdic["frames"][dirname + '/' + k] = v
        plistlib.writePlist(pdic, plistfile)

    @classmethod
    def excute(cls, packpath, tarpath, confkey, packtype="png", extparam=""):
        ''' 执行 '''
        cls._pconfs = []

        cls._basepath = packpath
        cls._tarpath = tarpath
        cls._resconf = cls.get_resconfig()

        conftmp = cls.chk_packconf(confkey)
        cls._pconfs.append(conftmp)
        cls._packtype = packtype
        cls._do_packlist(extparam)


if __name__ == "__main__":
    DEBUG = True
    if not DEBUG:
        sys.exit()

    b = "/data0/public_work/cocosstudio/resource_v2.0/"
    t = "/data0/public_work/git_xlhall_new/project/trunk/"
    l = "xlv3"
    BatchPackimg.excute(b, t, l)



# encoding:utf8

'''删除某一个类型的文件'''

import os

def iter_public(path, typename):
    for filename in os.listdir(path):
        fileobj = os.path.join(path, filename)
        if os.path.isfile(fileobj):
            if filename.endswith(typename):
                os.remove(fileobj)
                print ("Del the file-->>%s" % fileobj)
        else:
            iter_public(fileobj, typename)


# encoding:utf8

'''
Code for xl-tool helper functions!
'''
import os
import json
import logging

KERROR_OPENCFG = {
    "open_failed": "Target cfgfile read failed!",
    "decode_failed": "Cfgfile decode error!",
    "keynot_exist": "Must set param not satisfy!"
}


def raise_error(codek):
    str_err = KERROR_OPENCFG.get(codek)
    logging.error(str_err)
    return (False, str_err)


class DUtil(object):
    @staticmethod
    def get_xlcfg(cfgfile, **kwads):
        strcfg = None
        try:
            with open(cfgfile, "r") as fp:
                strcfg = fp.read()
                fp.close()
        except IOError as identifier:
            logging.debug(identifier)
            return raise_error("open_failed")

        try:
            cfgdic = json.loads(strcfg)
        except (TypeError, ValueError) as identifier:
            logging.debug(identifier)
            return raise_error("decode_failed")

        if kwads.has_key("limitks") > 0:
            for k, _ in cfgdic.items():
                if k not in kwads.get("limitks"):
                    return raise_error("keynot_exist")
        return (True, cfgdic)


__all__ = [
    "DUtil"
]


# encoding:utf8
''' sqlite3库封装 '''
import os
import sys
import sqlite3
import logging
from functools import wraps


def db_chk_course(method):
    ''' 数据库、游标检查 '''
    @wraps(method)
    def _tarfunc(self, *args, **kwads):
        if self.conn() is None:
            logging.error("Not create the conn yet!")
            return
        if self.course() is None:
            logging.error("Not find the db-course yet!")
            return
        return method(self, *args, **kwads)
    return _tarfunc


class SqliteObj(object):
    ''' 连接实例 '''
    _conn = None                # 链接实例
    _conncour = None            # 游标
    _isdebug = True             # 是否是开发调试

    TBCONF_NAME = dict(         # 表结构默认
        int="int(11)",
        str="varchar(20)"
    )

    DATA_FORAMTFUNC = dict(     # 表内数据格式转换
        int=lambda val: str(int(val)) + ",",
        str=lambda val: "'{val}'".format(val=val)
    )

    DB_COMMANDS = dict(         # 数据库操作文本
        newtb='''CREATE TABLE IF NOT EXISTS {tbname} ({tbchk} PRIMARY KEY('{privatekey}'))''',
        insert='''INSERT INTO {tbname} VALUES ({datachk})''',
        getdata='''SELECT * FROM {tbname} WHERE {condition}''',
        getcount='''SELECT COUNT * FROM {tbname} WHERE {condition}''',
        insertlist='''INSERT INTO {tbname} VALUES {datachk}''',
        update='''UPDATE {tbname} SET {valstr} WHERE {condition}'''
    )

    def __init__(self, dbfile):
        if (os.path.isfile(dbfile)) and (self._isdebug is False):
            logging.error("DB is still exist! Del it first!")
            sys.exit()
        if self._conn is None:
            self._conn = sqlite3.connect(dbfile)
            self._conncour = self._conn.cursor()

    def __del__(self):
        if self._conncour:
            logging.info("Close clourse")
            self._conncour.close()

    def conn(self):
        ''' 库连接 '''
        return self._conn

    def course(self):
        ''' 库游标 '''
        return self._conncour

    def _chk_tbocnf(self, tbconf):
        cmd_str = ""
        for col in tbconf:
            for key, keytype in col.items():
                cmd_str += "'{key}' {keyval} NOT NULL,".format(
                    key=key, keyval=self.TBCONF_NAME[keytype])
        return cmd_str

    def _chk_insert(self, datacont):
        cmd_str = ""
        for valtype, val in datacont.items():
            relvaltype = valtype[:3]
            relindex = int(valtype[-1]) - 1
            cmd_str += self.DATA_FORAMTFUNC[relvaltype](val) + ","
        return cmd_str[:-1]

    def _chk_insertlist(self, datalist):
        ret = ""
        cmd_str = ""
        for dataobj in datalist:
            liststr = "({}),"
            listval = []
            for valtype, val in dataobj.items():
                relvaltype = valtype[:3]
                relindex = int(valtype[-1]) - 1
                listval.insert(
                    relindex, self.DATA_FORAMTFUNC[relvaltype](val) + ",")
            cmd_str += liststr.format("".join(listval)[:-1])
            ret += cmd_str
        return ret[:-1]

    @db_chk_course
    def _excute_cmd(self, cmdstr):
        ''' 执行SQL命令 '''
        logging.debug("insert cmd->>>%s", cmdstr)
        try:
            cu = self._conncour.execute(cmdstr)
            self._conn.commit()
            return cu
        except sqlite3.OperationalError as excuterr:
            logging.error(
                "\n============\nsqlite excute %s error!\n%s\n============\n", cmdstr, excuterr)
            return
        except sqlite3.IntegrityError as interr:
            logging.error(
                "\n============\nsqlite excute %s error!\n%s\n============\n", cmdstr, interr)
            return

    @db_chk_course
    def create_table(self, tbname, tbconf, privatekey=""):
        ''' 创建表 '''
        if privatekey is "":
            keylist = list(tbconf[0].keys())
            privatekey = keylist[0]
        logging.debug("--->>privatekey  %s", privatekey)
        tbchk = self._chk_tbocnf(tbconf)
        cmd_str = self.DB_COMMANDS["newtb"].format(
            tbname=tbname, tbchk=tbchk, privatekey=privatekey)
        self._excute_cmd(cmd_str)

    @db_chk_course
    def get_data(self, tbname, condition):
        ''' 获取数据 '''
        cmd_str = self.DB_COMMANDS["getdata"].format(
            tbname=tbname, condition=condition)
        cu = self._excute_cmd(cmd_str)
        return cu.fetchall()

    @db_chk_course
    def get_keycount(self, tbname, condition):
        ''' 获取字段数量 '''
        cmd_str = self.DB_COMMANDS["getcount"].format(
            tbname=tbname, condition=condition)
        self._excute_cmd(cmd_str)

    @db_chk_course
    def insert_data(self, tbname, dbdata):
        ''' 添加单条数据 '''
        cmd_str = self.DB_COMMANDS["insert"].format(
            tbname=tbname, datachk=self._chk_insert(dbdata))
        self._excute_cmd(cmd_str)

    @db_chk_course
    def insert_datalist(self, tbname, dbdatalist):
        ''' 添加多条数据 '''
        cmd_str = self.DB_COMMANDS["insertlist"].format(
            tbname=tbname, datachk=self._chk_insertlist(dbdatalist))
        self._excute_cmd(cmd_str)

    @db_chk_course
    def update_data(self, tbname, valstr, condition):
        ''' 更新单条数据 '''
        cmd_str = self.DB_COMMANDS["update"].format(
            tbname=tbname, valstr=valstr, condition=condition)
        self._excute_cmd(cmd_str)

    @db_chk_course
    def close(self):
        ''' 关闭连接 '''
        self._conncour.close()


class SqliteMgr(object):
    ''' sqlite单例 '''
    _dbobj = None  # 连接单例

    @classmethod
    def inc(cls, dbfile=""):
        ''' inc '''
        if cls._dbobj is None:
            cls._dbobj = SqliteObj(dbfile)
        return cls._dbobj

    @classmethod
    def close_all(cls):
        ''' 关闭连接 '''
        cls._dbobj.close()
        del cls._dbobj


__all__ = [
    "SqliteMgr"
]

if __name__ == "__main__":

    '''
    usage:
    TBNAME = "RES_MD5"
    TBCONF = dict(
        id="int",
        number="str"
    )

    DATACONT = dict(
        int=1,
        str="1231ada"
    )

    SqliteMgr.inc("C:\\testsqlite.db").create_table(TBNAME, TBCONF, "id")
    SqliteMgr.inc("C:\\testsqlite.db").insert_data(TBNAME, DATACONT)
    SqliteMgr.close_all()

    '''



# encoding:utf-8
import os
import sys

try:
    from py_ex import *
except:
    import logging
from PIL import Image


def _path_fmt(path):
    return path.replace("/", os.sep)


def resizeBatch(texture, sizelist, tarlist):
    img = Image.open(texture)
    index = 0
    tmpimg = {}
    for size in sizelist:
        tmpimg[index] = img.resize((size, size), Image.ANTIALIAS)

        path_base = os.path.split(tarlist[index])[0]
        if not os.path.isdir(path_base):
            os.mkdir(path_base)

        tmpimg[index].save(tarlist[index])
        logging.debug("Resize the image [%s] to [%s] (%s)" % (
            texture, tarlist[index], size))
        index = index + 1


def resizeSingle(texture, sizew, sizeh, tardir):
    img = Image.open(texture)
    img.resize((sizew, sizeh), Image.ANTIALIAS)

    path_base = os.path.splie(texture)[0]
    filename_base = os.path.splie(texture)[1]

    try:
        tarfile = os.path.join(tardir, filename_base)
        if os.path.isfile(tarfile):
            os.remove(tarfile)
        ret.save(tarfile)
        logging.debug("Resize the Imgge [%s] to [%s]" % (texture, tardir))
    except:
        logging.error("@!Save texture failed")


def pack_platicon(basetexture, topath, platform="android"):
    if platform == "android":
        sizelist = [72, 72, 36, 48, 96, 144]
        pathlist = [_path_fmt(topath + "/drawable/icon.png"), _path_fmt(topath + "/drawable-hdpi/icon.png"), _path_fmt(topath + "/drawable-ldpi/icon.png"),
                    _path_fmt(topath + "/drawable-mdpi/icon.png"), _path_fmt(topath + "/drawable-xhdpi/icon.png"), _path_fmt(topath + "/drawable-xxhdpi/icon.png")]
        resizeBatch(basetexture, sizelist, pathlist)

    elif platform == "ios":
        sizelist = [29, 36, 40, 48, 50, 57, 58, 72, 76, 80, 87,
                    96, 100, 114, 120, 121, 144, 152, 167, 180, 181, 512]
        tarlist = ["Icon-29.png", "Icon-36.png", "Icon-40.png", "Icon-48.png", "Icon-50.png",
                   "Icon-57.png", "Icon-58.png", "icon-72.png", "Icon-76.png",
                   "Icon-80.png", "Icon-87.png", "Icon-96.png", "Icon-100.png",
                   "Icon-114.png", "Icon-120.png", "Icon-121.png", "Icon-144.png",
                   "Icon-152.png", "Icon-167.png", "Icon-180.png", "Icon-181.png", "Icon-512.png"]
        reltarlist = []
        for iconname in tarlist:
            reltarlist.append(_path_fmt(topath + "/%s" % iconname))

        resizeBatch(basetexture, sizelist, reltarlist)



import os
import shutil 
import json
import logging

class TextureFmt(object):

    _texturelist = []

    @classmethod
    def _handlepng8(cls, fileobj):
        cmd_str = "pngquant --force --output {outfile} {basefile}"
        print("Formst texture %s to png8.." % fileobj.split(os.sep)[-1])
        os.system(cmd_str.format(outfile=fileobj , basefile=fileobj))

    @classmethod
    def _fmtpng8(cls):
        for fileobj in cls._texturelist:
            cls._handlepng8(fileobj

    @classmethod
    def _fmtpvr(cls):
        for fileobj in cls._texturelist:
            cls._handlepvr(fileobj)

    @classmethod
    def _get_texture(cls, path):
        for filename in os.listdir(path):
            fileobj = os.path.join(path, filename)
            if os.path.isfile(fileobj):
                if filename.endswith(".png"):
                    cls._texturelist.append(fileobj)
            else:
                cls._get_texture(fileobj)

    @classmethod
    def excute(cls, tarpath):
        cls._get_texture(tarpath)
        strlist = json.dumps(cls._texturelist, sort_keys = True, indent = 4)
        # cls._fmtpng8()
        cls._fmppvr()

if __name__ == "__main__":
    TextureFmt.excute(os.getcwd())


# encoding:utf8
# !/usr/bin/env python

import os
import sys
import shutil


def add_path_prefix(path_str):
    """ Compatible windows-sys filepath """
    if sys.platform != "win32":
        return path_str

    if path_str.startswith("\\\\?\\"):
        return path_str

    ret = "\\\\?\\" + os.path.abspath(path_str)
    ret = ret.replace("/", "\\")
    return ret


def get_dirname(path):
    """ Get current path dirname. """
    if not os.path.isdir(path):
        return
    tmp = path.split("\\")
    name = tmp[len(tmp) - 1]
    return name


def copy_dirfiles_to(fromdir, todir):
    """ Copy all files from $fromdir to $todir|both path must exist! """
    if not os.path.isdir(todir):
        os.makedirs(todir)
    for item in os.listdir(fromdir):
        path = os.path.join(fromdir, item)
        if os.path.isfile(path):
            path = add_path_prefix(path)
            copy_dst = add_path_prefix(todir)
            shutil.copy(path, copy_dst)
        if os.path.isdir(path):
            new_dst = os.path.join(todir, item)
            if not os.path.isdir(new_dst):
                os.makedirs(add_path_prefix(new_dst))
            copy_dirfiles_to(path, new_dst)


def re_pathfile_postifix(path, beflist, tolist):
    """ Change all file-postifix $beflist to $tolist """
    newname = ""
    for typename in beflist:
        for filename in os.listdir(path):
            item = os.path.join(path, filename)
            if os.path.isfile(item) and os.path.basename(filename).find(typename) != -1:
                newname = tolist[beflist.index(typename)]
                os.rename(item, newname)
            if os.path.isdir(item):
                re_pathfile_postifix(item, beflist, tolist)


def del_postifix_files(path, typelist):
    """ Del all file end with $typelist's postifix """
    for typename in typelist:
        for filename in os.listdir(path):
            item = os.path.join(path, filename)
            if os.path.isfile(item) and os.path.basename(filename).find(typename) != -1:
                os.remove(item)
            if os.path.isdir(item):
                del_postifix_files(item, typelist)



# encoding:utf-8


import sys
sys.path.append("./py_lib")
from py_lib import remote  # noqa
import logging  # noqa


def test_remote():
    HOST = "172.16.50.45"
    PORT = 22
    con = remote.RemoteCtrl(HOST, PORT, pwd="123456")
    ret = con.ssh_command("ls")
    print(con.ssh_command("cd /data0/"), "cd result")
    ret2 = con.ssh_command("ls")
    # logging.warning(ret, "--->>ret")
    print(ret)
    print(ret2)


def test_ftp():
    con = remote.RemoteCtrl(
        "118.25.105.42", usr="CeshiClinetFo", pwd="CeshiClinetFo@!@#")
    con.ftp_upload("/data0/private_git/dating_qq.apk",
                   "/usr/local/openresty/nginx/xpm/dldevbins/dating_qq.apk")


def test_sftp():
    con = remote.RemoteCtrl(
        "172.16.50.45", usr="root", pwd="123456"
    )
    con.sftp_upload("/data0/private_git/dating_qq.apk",
                    "/usr/local/openresty/nginx/xpm/dldevbins/dating_qq.apk")


class DTest:
    def test_pylib(self):
        test_remote()

    def test_ftpupload(self):
        test_ftp()


if __name__ == "__main__":
    t = DTest()
    # t.test_pylib()
    # t.test_ftpupload()
    test_sftp()



# encodint:utf8

import requests
from contextlib import closing
import json
import sys
import logging
if sys.version_info < (3, 0):
    from urlparse import urljoin  # noqa
else:
    from urllib.parse import urljoin  # noqa

DEFAULT_HTTP_TIMEOUT = 5


def get_fullurl(baseurl, relurl):
    return urljoin(baseurl, relurl)


class _HttpRequest(object):
    def __init__(self):
        pass

    def execute(self, url, dicparams, method, **kwads):
        try:
            ret = None
            mname = method.upper()
            if mname == "POST":
                ret = requests.post(url, json=dicparams, **kwads)
            elif mname == "GET":
                ret = requests.get(url, params=dicparams, **kwads)

            if ret.status_code == 200:
                return (True, ret.text)
            else:
                logging.error(
                    "Httprequest <method=%s url=%s> raise error!", method, url)

        except requests.exceptions.ConnectionError as identifier:

            logging.error("Http <method=%s url=%s> raise error! \n%s",
                          method, url,
                          str(identifier))
        return (False, None)


class DHttp(object):

    _baseurl = ""

    @classmethod
    def set_baseurl(cls, host):
        cls._baseurl = host

    @classmethod
    def http_get(cls, relurl, dicparams, **kwads):
        (issuc, resp) = _HttpRequest().execute(get_fullurl(cls._baseurl, relurl),
                                               dicparams, "GET", **kwads)
        if issuc:
            try:
                return json.loads(resp, encoding="utf-8")
            except (TypeError, json.decoder.JSONDecodeError) as dec_err:
                logging.error("json decode error")
            else:
                pass

    @classmethod
    def http_post(cls, relurl, dicparams, **kwads):
        (issuc, resp) = _HttpRequest().execute(get_fullurl(cls._baseurl, relurl),
                                               dicparams, "POST", **kwads)
        if issuc:
            try:
                return json.loads(resp, encoding="utf-8")
            except (TypeError, json.JSONDecodeError) as dec_err:
                logging.error("json decode error")
            else:
                pass

    @classmethod
    def download_file(cls, relurl, tarf, process_cb=None, **kwads):
        with closing(requests.get(relurl, stream=True, verify=False)) as r:
            fsize = int(r.headers['content-length'])
            chunk_size = 1024
            nsize = 0
            with open(tarf, "wb") as fp:
                for data in r.iter_content(chunk_size=chunk_size):
                    psize = len(data)
                    nsize += psize
                    fp.write(data)
                    if hasattr(process_cb, '__call__'):
                        process_cb(nsize, fsize)


if __name__ == "__main__":
    DHttp.set_baseurl("https://api.heyzf.com")
    resp = DHttp.http_post("/v1/wstrade/takeout/cargolist?min=1&max=20",
                           {"sign": "123!@#xlmake", "ver": "1.1.1"}, verify=False)



#!/usr/bin/env python
# -*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: LiangjunFeng
# Mail: zhumavip@163.com
# Created Time:  2018-4-16 19:17:34
#############################################

from setuptools import setup, find_packages  # 这个包没有的可以pip一下
import os
import json
import shutil

if os.path.isdir("./dist"):
    shutil.rmtree("./dist")

setup(
    name="mgamedev",  # 这里是pip项目发布的名称
    version="0.1.8",  # 版本号，数值大的会优先被pip
    keywords=("dwb"),
    description="Private tools for develop mobile client games",
    long_description="All is poor extension!Don't use!",
    license="Mozilla Licence",

    url="https://gitee.com/heyzf/pytools_2dx",  # 项目相关文件地址，一般是github
    author="dwb",
    author_email="dwb@dwb.ren",

    packages=find_packages(),
    include_package_data=True,
    package_dir=[],
    install_requires=[],  # 这个项目需要的第三方库
    data_files=[]  # 这个项目需要的第三方库
)


# encoding:utf8
from lupa import _lupa as lupaerr
from lupa import LuaRuntime
import os
import sys
import shutil
import logging


LUACODE_INITCFG = '''
    package.path = package.path..";{tpath}/?"
    require ("{cfgf}")
'''


class LuabaseTool:

    _luabin = None
    _luagval = None

    _tmpdir = None

    def __init__(self):
        self.__init_luaenv()

    def lua_dofile(self, luaf):
        tpath = os.path.abspath(os.path.dirname(luaf))
        cfgf = luaf.split(os.sep)[-1]
        self.lua_dostring(LUACODE_INITCFG.format(
            tpath=tpath, cfgf=cfgf))
        self._luagval = self._luabin.globals()

    def __init_luaenv(self):
        self._luabin = LuaRuntime()

    def raise_err(self, errdesc):
        logging.error(errdesc)
        sys.exit()

    def lua_dostring(self, tarstr):
        logging.debug("run lua code:%s", tarstr)
        try:
            ret = self._luabin.execute(tarstr)
            return ret
        except lupaerr.LuaError as lerr:
            self.raise_err("Raise lua error! tracebck is->\n%s" % lerr)

    def lua_val(self, key):
        if not self._luagval:
            return None
        return self._luagval[key]

    def crt_tempdir(self, tmpdir):
        if os.path.isdir(tmpdir):
            shutil.rmtree(tmpdir)
        logging.info("Create the temporary dirpath->%s", tmpdir)
        os.makedirs(tmpdir)
        self._tmpdir = tmpdir
        return tmpdir

    def del_tempdir(self):
        if os.path.isdir(self._tmpdir):
            shutil.rmtree(self._tmpdir)

    def get_tempdir(self):
        return self._tmpdir


__all__ = [
    "LuabaseTool"
]



import os
import sys
import subprocess
import logging
import re
import json


def __suc(procename):
    logging.warning("[kill_process] kill process <%s> suc!", procename)


def __not():
    logging.warning("[kill_process] nothing to kill")


def kill_process(procename):
    cmd_killall = "killall %s" % procename
    ret = subprocess.Popen(cmd_killall, shell=True,
                           stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    sout, serr = ret.communicate()
    if ret.returncode == 0:
        __suc(procename)
    else:
        cmd_findone = "ps -ef | grep %s" % procename
        ret = subprocess.Popen(cmd_findone, shell=True,
                               stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
        sout, serr = ret.communicate()
        proce_list = re.split("\n+", sout.decode("utf-8"))
        if len(proce_list) > 1:
            for proce in proce_list:
                infos = re.split("\s+", proce)
                if procename in infos\
                        and ("grep" not in infos)\
                        and (__file__ not in infos):
                    ret = subprocess.Popen("kill -9 %s" %
                                           str(infos[2]), shell=True)
                    retcode = ret.wait()
                    if (retcode == 0):
                        __suc("PID:%s" % str(infos[2]))
        else:
            __not()


if __name__ == "__main__":
    proc_name = sys.argv[1]
    kill_process(proc_name)



# Courtesy http://plumberjack.blogspot.com/2010/12/colorizing-logging-output-in-terminals.html
# Tweaked to use colorama for the coloring

import colorama
import logging
import re
import sys


def remove_ansi(s):
    ansi_escape = re.compile(r'(\x9B|\x1B\[)[0-?]*[ -\/]*[@-~]')
    return ansi_escape.sub('', s)


class ColorizingStreamHandler(logging.StreamHandler):
    color_map = {
        logging.DEBUG: colorama.Style.DIM + colorama.Fore.CYAN,
        logging.WARNING: colorama.Fore.YELLOW,
        logging.ERROR: colorama.Fore.RED,
        logging.CRITICAL: colorama.Back.RED,
    }

    def __init__(self, stream, color_map=None):
        logging.StreamHandler.__init__(self,
                                       colorama.AnsiToWin32(stream).stream)
        if color_map is not None:
            self.color_map = color_map

    @property
    def is_tty(self):
        isatty = getattr(self.stream, 'isatty', None)
        return isatty and isatty()

    def format(self, record):
        message = logging.StreamHandler.format(self, record)
        if self.is_tty:
            # Don't colorize a traceback
            parts = message.split('\n', 1)
            parts[0] = self.colorize(parts[0], record)
            message = '\n'.join(parts)
        else:
            message = remove_ansi(message)
        return message

    def colorize(self, message, record):
        try:
            return (self.color_map[record.levelno] + message +
                    colorama.Style.RESET_ALL)
        except KeyError:
            return message


__all__ = [
    "ColorizingStreamHandler"
]

logger = logging.getLogger('test')
if __name__ == '__main__':
    handler = ColorizingStreamHandler(sys.stdout)
    formatter = logging.Formatter('%(message)s')
    handler.setFormatter(formatter)
    logger.addHandler(handler)
    logger.setLevel(logging.DEBUG)

    logger.debug('debug message')
    logger.info('info message')
    logger.warning('warning message')
    logger.error('error message')
    logger.critical('critical message')
    logger.error(colorama.Fore.BLUE + 'something' + colorama.Style.RESET_ALL)
